@@ -1,13 +1,25 @@
 /*
-  Copyright (c) 1999 Rafal Wojtczuk <nergal@avet.com.pl>. All rights reserved.
+  Copyright (c) 1999 Rafal Wojtczuk <nergal@7bulls.com>. All rights reserved.
   See the file COPYING for license details.
 */
 
 #ifndef _NIDS_NIDS_H
-#define _NIDS_NIDS_H
-#define NIDS_MAJOR 1
-#define NIDS_MINOR 18
-#include <sys/types.h>
+# define _NIDS_NIDS_H
+
+# include <sys/types.h>
+#include <netinet/in_systm.h>
+#include <netinet/in.h>
+# include <netinet/ip.h>
+# include <netinet/tcp.h>
+# include <pcap.h>
+
+# ifdef __cplusplus
+extern "C" {
+# endif
+
+# define NIDS_MAJOR 1
+# define NIDS_MINOR 24
+
 enum
 {
   NIDS_WARN_IP = 1,
@@ -30,12 +42,15 @@ enum
   NIDS_WARN_TCP_BADFLAGS
 };
 
-#define NIDS_JUST_EST 1
-#define NIDS_DATA 2
-#define NIDS_CLOSE 3
-#define NIDS_RESET 4
-#define NIDS_TIMED_OUT 5
-#define NIDS_EXITING   6	/* nids is exiting; last chance to get data */
+# define NIDS_JUST_EST 1
+# define NIDS_DATA 2
+# define NIDS_CLOSE 3
+# define NIDS_RESET 4
+# define NIDS_TIMED_OUT 5
+# define NIDS_EXITING   6	/* nids is exiting; last chance to get data */
+
+# define NIDS_DO_CHKSUM  0
+# define NIDS_DONT_CHKSUM 1
 
 struct tuple4
 {
@@ -69,7 +84,9 @@ struct half_stream
   u_int urg_ptr;
   u_short window;
   u_char ts_on;
+  u_char wscale_on;
   u_int curr_ts; 
+  u_int wscale;
   struct skbuff *list;
   struct skbuff *listtail;
 };
@@ -88,6 +105,8 @@ struct tcp_stream
   struct tcp_stream *prev_time;
   int read;
   struct tcp_stream *next_free;
+  void *user;
+  long ts;
 };
 
 struct nids_prm
@@ -108,21 +127,60 @@ struct nids_prm
   char *pcap_filter;
   int promisc;
   int one_loop_less;
+  int pcap_timeout;
+  int multiproc;
+  int queue_limit;
+  int tcp_workarounds;
+  pcap_t *pcap_desc;
+  int tcp_flow_timeout;
 };
 
-int nids_init ();
+struct tcp_timeout
+{
+  struct tcp_stream *a_tcp;
+  struct timeval timeout;
+  struct tcp_timeout *next;
+  struct tcp_timeout *prev;
+};
+
+int nids_init (void);
 void nids_register_ip_frag (void (*));
+void nids_unregister_ip_frag (void (*));
 void nids_register_ip (void (*));
+void nids_unregister_ip (void (*));
 void nids_register_tcp (void (*));
+void nids_unregister_tcp (void (*x));
 void nids_register_udp (void (*));
+void nids_unregister_udp (void (*));
 void nids_killtcp (struct tcp_stream *);
 void nids_discard (struct tcp_stream *, int);
-void nids_run ();
-int nids_getfd ();
-int nids_next ();
+int nids_run (void);
+void nids_exit(void);
+int nids_getfd (void);
+int nids_dispatch (int);
+int nids_next (void);
+void nids_pcap_handler(u_char *, struct pcap_pkthdr *, u_char *);
+struct tcp_stream *nids_find_tcp_stream(struct tuple4 *);
+void nids_free_tcp_stream(struct tcp_stream *);
 
 extern struct nids_prm nids_params;
 extern char *nids_warnings[];
 extern char nids_errbuf[];
+extern struct pcap_pkthdr *nids_last_pcap_header;
+extern u_char *nids_last_pcap_data;
+extern u_int nids_linkoffset;
+extern struct tcp_timeout *nids_tcp_timeouts;
+
+struct nids_chksum_ctl {
+	u_int netaddr;
+	u_int mask;
+	u_int action;
+	u_int reserved;
+};
+extern void nids_register_chksum_ctl(struct nids_chksum_ctl *, int);
+
+# ifdef __cplusplus
+}
+# endif
 
 #endif /* _NIDS_NIDS_H */
